@@ -1,7 +1,7 @@
 import inspect
 from .smarterStore import SmarterStore
 from abc import ABCMeta, abstractmethod
-from typing import Callable, Optional, Any
+from typing import Callable, Optional, Any, Tuple, List
 
 
 class SmarterMessage(dict):
@@ -248,19 +248,42 @@ class SmarterSender:
         user_id = return_message.get("user", {}).get("id")
         return self.__get_usage(user_id=user_id)
 
-    def get_event_collection(self):
-        return self.__db.get_collection(collection_name=f"events_{self.__user_id}")
+    def query_data_lake(self, sql_query: str, args=None, paramstyle: str = "format", commit=True) -> Tuple:
+        """
+        Takes an SQL query on the data lake and returns all remaining rows of a query result.
+        Args:
+            :param sql_query: The SQL statement to execute on the data Lake
+            :param args: If :`paramstyle` is ``qmark``, ``numeric``, or ``format``,
+                this argument should be an array of parameters to bind into the
+                statement.  If :data:`paramstyle` is ``named``, the argument should
+                be a dict mapping of parameters.  If the `paramstyle` is
+                ``pyformat``, the argument value may be either an array or a
+                mapping.
+            :param paramstyle: can be one of ('qmark', 'numeric', 'format','named', 'pyformat')
+            :param commit: commits the database update permanently
+        Returns:
+            A sequence, each entry of which is a sequence of field values
+            making up a row.:tuple
+        """
+        data = self.__db.execute_sql_query(query=sql_query,
+                                           args=args,
+                                           paramstyle=paramstyle,
+                                           commit=commit,
+                                           fetch="all")
+        return data
 
-    def get_static_collection(self):
-        return self.__db.get_collection(collection_name=f"static_{self.__user_id}")
+    def write_dataframe_to_lake(self, df, table_name: str) -> None:
+        self.__db.write_from_dataframe(df=df, table_name=table_name)
 
-    def get_sources(self) -> list:
-        collection = self.__db.get_collection("smarterSource")
-        result = collection.find({"userEmail": self.__user_email})
-        return list(result)
+    def bulk_insert_to_lake(self, file_name: str, table_name: str, delimiter: str, column_names: List[str],
+                            parameter_indices: List[int], batch_size: int = 1):
 
-    def add_tag(self, is_event, tag_id, new_tag, new_val):
-        self.__db.add_tag(is_event=is_event, tag_id=tag_id, new_tag=new_tag, new_val=new_val, user_id=self.__user_id)
+        self.__db.bulk_insert(file_name=file_name,
+                              table_name=table_name,
+                              batch_size=batch_size,
+                              delimiter=delimiter,
+                              parameter_indices=parameter_indices,
+                              column_names=column_names)
 
 
 class _Smarter_SignatureCheckerMeta(ABCMeta):
